@@ -40,8 +40,8 @@ class GmailClient(EmailClient):
     def extract_from_html(self, string):
         try:
             parsed = BeautifulSoup(string, "lxml")
-            if parsed.div is not None:
-                gmail_quote = parsed.div.find("div", class_ = "gmail_quote")
+            gmail_quote = parsed.find("div", class_ = "gmail_quote")
+            if gmail_quote is not None:
                 if gmail_quote.div is None:
                     body = ''.join(str(tag).strip() for tag in gmail_quote.contents[18:])
                     date = datetime.datetime.strptime(gmail_quote.contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
@@ -56,8 +56,8 @@ class GmailClient(EmailClient):
                     sender = gmail_quote.span.a.get_text()
                 return {"body" : body, "sender" : sender, "date" : date}
             else:
-                raise ExtractionError("Parsing of forward failed.")
-                
+                raise ExtractionError("Parsing of forward failed. No div with class gmail_quote was found.")
+               
         except Exception as e:
             raise ExtractionError("Given email did not parse successfully: " + str(e))
 
