@@ -48,7 +48,7 @@ class Extractor:
             if isinstance(payloads, list):
                 for payload in payloads:
                     if payload.get('content-type').startswith('text/html'):
-                        payload_string = quopri.decodestring(payload.get_payload())
+                        payload_string = quopri.decodestring(payload.get_payload().encode('utf8'))
                         return self.extract_from_html(payload_string)
                     elif payload.get('content-type').startswith('multipart/alternative'):
                         return process_payload(payload.get_payload())
