@@ -22,6 +22,7 @@ import sys
 from unforward.errors import NoForwardFoundError
 from unforward.errors import ExtractionError
 import logging
+from pprint import pprint
 
 def main():
     """ The main starting point for the unforward script."""
@@ -39,6 +40,9 @@ def main():
     except ExtractionError as e:
         logging.exception("")
         exit(2)
+    except NotImplementedError as e:
+        logging.exception("")
+        exit(1)
     except NoForwardFoundError as e:
         logging.exception("")
         exit(1)
